@@ -7,7 +7,7 @@ qCEWNB<-function(p, alpha, beta, theta, s, lambda, log.p = FALSE, lower.tail = T
 	qf <- rep(NaN, length(p))
 	t=1/lambda*(1-(((p[p >= 0 & p <= 1]*(((1-lambda)^(-s))-1))+1)^(-1/s)))
 
-	qf[p >= 0 & p <= 1] <- (-1/alpha*log(1-(t)^(1/theta)))^(beta)
+	qf[p >= 0 & p <= 1] <- (-1/alpha*log(1-(t)^(1/theta)))^(1/beta)
     return(qf)
 	}
 
